@@ -82,6 +82,17 @@ func (c *SegmentContext) GetParentSegmentID() string {
 	return c.ParentSegmentID
 }
 
+func (c *SegmentContext) GetCorrelationContextValue(key string) string {
+	return c.CorrelationContext[key]
+}
+
+func (c *SegmentContext) SetCorrelationContextValue(key, value string) {
+	c.CorrelationContext[key] = value
+	if value == "" {
+		delete(c.CorrelationContext, key)
+	}
+}
+
 type SegmentSpan interface {
 	TracingSpan
 	GetSegmentContext() SegmentContext
