@@ -49,6 +49,7 @@ type Agent struct {
 	InstanceEnvName StringValue `yaml:"instance_env_name"`
 	Sampler         StringValue `yaml:"sampler"`
 	Meter           Meter       `yaml:"meter"`
+	Correlation     Correlation `yaml:"correlation"`
 }
 
 type Reporter struct {
@@ -97,6 +98,11 @@ type Plugin struct {
 	Excluded StringValue  `yaml:"excluded"`
 }
 
+type Correlation struct {
+	MaxKeyCount  StringValue `yaml:"max_key_count"`
+	MaxValueSize StringValue `yaml:"max_value_size"`
+}
+
 func LoadConfig(path string) error {
 	// load the default config
 	defaultConfig, err := defaultAgentFS.ReadFile("agent.default.yaml")
