@@ -107,8 +107,9 @@ func (i *Instrument) CouldHandle(opts *api.CompileOptions) bool {
 		// check the version of the framework could handler
 		version, err := i.tryToFindThePluginVersion(opts, ins)
 		if err != nil {
-			logrus.Warnf("ignore the plugin %s, because: %s", ins.Name(), err)
-			continue
+			// Local package (e.g. replaced toolkit) does not have version.
+			// So when the version is not detected, we should not skip it.
+			logrus.Warnf("the plugin %s %s", ins.Name(), err)
 		}
 
 		if ins.VersionChecker(version) {
@@ -340,7 +341,7 @@ func (i *Instrument) processPluginConfig(fileContent []byte) error {
 	return nil
 }
 
-//nolint
+// nolint
 func (i *Instrument) copyOperatorsFS(context *rewrite.Context, baseDir, packageName string) ([]string, error) {
 	result := make([]string, 0)
 	var debugBaseDir string
