@@ -18,6 +18,7 @@
 package plugins
 
 import (
+	traceactivation "github.com/apache/skywalking-go/plugin/trace"
 	"github.com/apache/skywalking-go/plugins/core/instrument"
 	"github.com/apache/skywalking-go/plugins/dubbo"
 	"github.com/apache/skywalking-go/plugins/gin"
@@ -25,10 +26,13 @@ import (
 	"github.com/apache/skywalking-go/plugins/go-restfulv3"
 	gorm_entry "github.com/apache/skywalking-go/plugins/gorm/entry"
 	gorm_mysql "github.com/apache/skywalking-go/plugins/gorm/mysql"
+	"github.com/apache/skywalking-go/plugins/grpc"
 	"github.com/apache/skywalking-go/plugins/http"
+	"github.com/apache/skywalking-go/plugins/irisv12"
 	"github.com/apache/skywalking-go/plugins/kratosv2"
 	"github.com/apache/skywalking-go/plugins/microv4"
 	"github.com/apache/skywalking-go/plugins/mongo"
+	"github.com/apache/skywalking-go/plugins/mux"
 	runtime_metrics "github.com/apache/skywalking-go/plugins/runtimemetrics"
 	sql_entry "github.com/apache/skywalking-go/plugins/sql/entry"
 	sql_mysql "github.com/apache/skywalking-go/plugins/sql/mysql"
@@ -47,6 +51,10 @@ func init() {
 	registerFramework(goredisv9.NewInstrument())
 	registerFramework(mongo.NewInstrument())
 	registerFramework(runtime_metrics.NewInstrument())
+	registerFramework(mux.NewInstrument())
+	registerFramework(grpc.NewInstrument())
+	registerFramework(irisv12.NewInstrument())
+	registerFramework(traceactivation.NewInstrument())
 
 	// gorm related instruments
 	registerFramework(gorm_entry.NewInstrument())
